.. code-block:: console

   API: an (incompatible) API change
   FIX: fix a bug or some other issue
   DEP: deprecate something, or remove a deprecated object
   DEV: development; change to dev tooling, make release
   DOC: documentation
   ENH: enhancement; add a feature
   CLN: clean; refactor, fix typo, add comment
   REV: revert an earlier commit
   STY: style fix (whitespace, PEP8)
   TST: tests; addition or modification
   TYP: static typing

